# AlertRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**octoprint_device** | **int** |  | [optional] 
**event_type** | [**AlertEventTypeEnum**](AlertEventTypeEnum.md) |  | [optional] 
**seen** | **bool** |  | [optional] 
**sent** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


